@@ -82,9 +82,7 @@ def create_role(session, role_policy, nr_account_id, tags):
                 {"ParameterKey": "PolicyName", "ParameterValue": role_policy_name},
             ],
             Capabilities=["CAPABILITY_NAMED_IAM"],
-            Tags=[{"Key": key, "Value": value} for key, value in tags]
-            if tags
-            else None,
+            Tags=[{"Key": key, "Value": value} for key, value in tags] if tags else [],
         )
         click.echo("Waiting for stack creation to complete...", nl=False)
         client.get_waiter("stack_create_complete").wait(StackName=stack_name)
@@ -148,7 +146,7 @@ def create_log_ingest_parameters(
 
 
 def import_log_ingestion_function(
-    session, nr_license_key, enable_logs, memory_size, timeout, role_name
+    session, nr_license_key, enable_logs, memory_size, timeout, role_name, tags
 ):
     parameters, capabilities = create_log_ingest_parameters(
         nr_license_key, enable_logs, memory_size, timeout, role_name, "IMPORT"
@@ -169,6 +167,7 @@ def import_log_ingestion_function(
             TemplateBody=template.read(),
             Parameters=parameters,
             Capabilities=capabilities,
+            Tags=[{"Key": key, "Value": value} for key, value in tags] if tags else [],
             ChangeSetType="IMPORT",
             ChangeSetName=change_set_name,
             ResourcesToImport=[
@@ -211,7 +210,7 @@ def create_log_ingestion_function(
         TemplateURL=template_url,
         Parameters=parameters,
         Capabilities=capabilities,
-        Tags=[{"Key": key, "Value": value} for key, value in tags] if tags else None,
+        Tags=[{"Key": key, "Value": value} for key, value in tags] if tags else [],
         ChangeSetType=mode,
         ChangeSetName=change_set_name,
     )
@@ -315,9 +314,7 @@ def update_log_ingestion_function(
             TemplateBody=json.dumps(template_body),
             Parameters=params,
             Capabilities=["CAPABILITY_IAM"],
-            Tags=[{"Key": key, "Value": value} for key, value in tags]
-            if tags
-            else None,
+            Tags=[{"Key": key, "Value": value} for key, value in tags] if tags else [],
         )
         client.get_waiter("stack_update_complete").wait(
             StackName=nested_stack["PhysicalResourceId"]
@@ -337,6 +334,7 @@ def update_log_ingestion_function(
             old_memory_size,
             old_timeout,
             role_name=old_role_name,
+            tags=tags,
         )
         # Now that we've unnested, do the actual update
 
@@ -478,7 +476,7 @@ def install_log_ingestion(
                     memory_size,
                     timeout,
                     role_name,
-                    tags,
+                    tags=tags,
                 )
             except Exception as e:
                 failure("Failed to create 'newrelic-log-ingestion' function: %s" % e)
@@ -506,6 +504,7 @@ def update_log_ingestion(
     memory_size=None,
     timeout=None,
     role_name=None,
+    tags=None,
 ):
     """
     Updates the New Relic AWS Lambda log ingestion function and role.
@@ -532,7 +531,13 @@ def update_log_ingestion(
         return False
     try:
         update_log_ingestion_function(
-            session, nr_license_key, enable_logs, memory_size, timeout, role_name
+            session,
+            nr_license_key,
+            enable_logs,
+            memory_size,
+            timeout,
+            role_name,
+            tags=tags,
         )
     except Exception as e:
         failure("Failed to update 'newrelic-log-ingestion' function: %s" % e)
@@ -617,7 +622,7 @@ def install_license_key(
                     Capabilities=["CAPABILITY_NAMED_IAM"],
                     Tags=[{"Key": key, "Value": value} for key, value in tags]
                     if tags
-                    else None,
+                    else [],
                     ChangeSetType=mode,
                     ChangeSetName=change_set_name,
                 )
